% The goal of this main program is to call 'nmhp', a piece of software
% that implements the Harker and Pang algorithm and an algorithm with
% exact linesearch for solving the linear complementarity problem (LCP)
%
%    0 <= x _|_ (M*x+q) >= 0.
%
% This piece of software is a complement to the paper "A lower bound on
% the iterative complexity of the Harker and Pang globalization
% technique of the Newton-min algorithm for solving the linear
% complementarity problem", by J.-P. Dussault, M. Frappier, and J.Ch.
% Gilbert, 2018.
%
% Author: J.Ch. Gilbert, Inria, April 2019.

% Matlab setting

  clear all;
  clf;
  format long;
  format compact;

% Modify the Matlab search path

  addpath ../src	% for nmhp

% Get data of the Fathi problem

  n  = 32;
  [M,q,xsol,x0] = fathi(n,1);

  % Test case of remark 4.1.5

% n  = 4;
% [M,q,xsol,x0] = fathi(n,1);
% x0 = ones(n,1)/31;
% x0 = ones(n,1)/30;
% x0 = [0;0;0;1/13];
% options.method  = 1;	% 0: Harker and Pang, 1: stepsize = (1-bs_cc)*alphab1+bs_cc*alphab2, 2: exact LS

  % Modification of the initial point suggested by Tangi Migot

% small = 0.2;
% q = -small.^([1:n]');

% Set options of the solver NMHP

  options.method  = 1;		% 0: Harker and Pang, 1: stepsize = (1-bs_cc)*alphab1+bs_cc*alphab2, 2: exact LS
  options.itermax = 99999;	% max number of iterations
  options.epshp   = 1.e-5;	% extra-stepsize for the Harker-Pang algorithm
  options.dxmin   = 1.e-11;	% resolution in x
  options.abstol  = 1.e-9;	% absolute tolerence
  options.verb    = 3;		% 0: silent, 1: one line per iteration, 2: standard, 3: more details

% Call the solver nmhp

  tstart = tic;  	% start CPU timer

  [x,info] = nmhp(M,q,x0,options);

  if info.flag == 0
    fprintf('\n(nmhp) output flag = %i\n(nmhp) number of iterations = %i\n(nmhp) number of QP solves = %i',info.flag,info.iter,info.qpsolve);
    if ~isempty(xsol); fprintf('\n(nmhp) L2 error on the solution = %11.5e',norm(x-xsol)); end
    fprintf('\n(nmhp) CPU time = %g sec\n',toc(tstart));
  end
